interface IOperations<T extends number | bigint = number> {
    ZERO: T;
    parse(s: string, start: number): [nextStart: number, value: T];
    add(a: T, b: T): T;
    subtract(a: T, b: T): T;
    multiply(a: T, b: T): T;
    divide(a: T, b: T): T;
}
declare const integerOperations: IOperations;
declare const decimalOperations: IOperations;
declare const bigintOperations: IOperations<bigint>;

declare type ICalculate<T extends number | bigint> = (expression: string) => T;
declare function createCalculate<T extends number | bigint>(operations: IOperations<T>, resolveExpression?: (s: string) => string): ICalculate<T>;
declare const calculate: ICalculate<number>;
declare const decimalCalculate: ICalculate<number>;
declare const bigintCalculate: ICalculate<bigint>;

declare enum TokenSymbol {
    DIGIT = 1,
    OPEN_PAREN = 2,
    CLOSE_PAREN = 3,
    PLUS = 4,
    MINUS = 5,
    MULTI = 6,
    DIVIDE = 7,
    END = 8,
    A = -1,
    B = -2,
    C = -3,
    D = -4,
    E = -5
}
/**
 * Priority map.
 */
declare const ll1IdxMap: Readonly<Record<string, TokenSymbol>>;
declare const idx: (c: string) => number;
declare const sddTable: number[][];
declare const MAX_TOKENS = 5;
declare const MAX_SYMBOLS = 8;
declare const ll1Table: Int8Array[];

export { ICalculate, IOperations, MAX_SYMBOLS, MAX_TOKENS, TokenSymbol, bigintCalculate, bigintOperations, calculate, createCalculate, decimalCalculate, decimalOperations, calculate as default, idx, integerOperations, ll1IdxMap, ll1Table, sddTable };
